@@ -2,18 +2,18 @@
 macro_rules! error {
     (
         $main_error_ident: ident {
-            $($current_error_ident: ident),+
+            $($current_error_ident: ident),*
         }
     ) => {
         #[derive(Debug)]
         pub enum $main_error_ident {
-            $($current_error_ident($current_error_ident)),+
+            $($current_error_ident($current_error_ident)),*
         }
 
         impl Display for $main_error_ident {
-            fn fmt(&self, f: &mut Formatter) -> Result {
+            fn fmt(&self, _f: &mut Formatter) -> Result {
                 match *self {
-                    $($main_error_ident::$current_error_ident(ref err) => write!(f, "{}", err)),+
+                    $($main_error_ident::$current_error_ident(ref err) => write!(_f, "{}", err)),*
                 }
             }
         }
@@ -21,13 +21,13 @@ macro_rules! error {
         impl Error for $main_error_ident {
             fn description(&self) -> &str {
                 match *self {
-                    $($main_error_ident::$current_error_ident(ref err) => err.description()),+
+                    $($main_error_ident::$current_error_ident(ref err) => err.description()),*
                 }
             }
 
             fn cause(&self) -> Option<&Error> {
                 match *self {
-                    $($main_error_ident::$current_error_ident(ref err) => Some(err)),+
+                    $($main_error_ident::$current_error_ident(ref err) => Some(err)),*
                 }
             }
         }
@@ -38,6 +38,6 @@ macro_rules! error {
                     $main_error_ident::$current_error_ident(error)
                 }
             }
-        )+
+        )*
     }
 }
